<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<!-- XSL Rule file to WCS Extracted Data to PECOS -->

<xsl:strip-space elements = "import" />

<xsl:output
  method = "text" 
  omit-xml-declaration = "yes"
  indent = "no"
/> 


<!-- Variable Name Definations Section Starts -->
   <xsl:variable name="FieldSeperator">,</xsl:variable>
   <xsl:variable name="RecordSeperator">&#13;&#10;</xsl:variable>   
   
   <!-- Global Variables -->
   <xsl:variable name="CIFVersion">CIF_I_V3.0</xsl:variable>      
   <xsl:variable name="CURRENCY">CURRENCY: </xsl:variable>      
   <xsl:variable name="mecur">USD,CAD</xsl:variable>
   <xsl:variable name="CHARSET">CHARSET: </xsl:variable>      
   <xsl:variable name="LOADMODE">LOADMODE: </xsl:variable>      
   <xsl:variable name="lmode">F</xsl:variable> 
   <xsl:variable name="SUPPLIERID_DOMAIN">SUPPLIERID_DOMAIN: </xsl:variable>      
   <xsl:variable name="supiddomain">DUNS</xsl:variable> 
   <xsl:variable name="CODEFORMAT">CODEFORMAT: </xsl:variable>      
   <xsl:variable name="codetype">UNSPSC</xsl:variable>      
   <xsl:variable name="COMMENTS">COMMENTS: </xsl:variable>      
   <xsl:variable name="DUNS">DUNS: </xsl:variable>      
   <xsl:variable name="dunsvalue">TRUE</xsl:variable>      
   <xsl:variable name="FIELDNAMES">FIELDNAMES: </xsl:variable>  
   <xsl:variable name="DATA">DATA</xsl:variable>         
   <xsl:variable name="ENDOFDATA">ENDOFDATA</xsl:variable>         
   <xsl:variable name="DefaultLeadTime">999</xsl:variable>      
   <xsl:variable name="seperator">_</xsl:variable> 
   <xsl:variable name="openbraces">{</xsl:variable> 
   <xsl:variable name="closebraces">}</xsl:variable> 
   <xsl:variable name="equals">=</xsl:variable> 
   <xsl:variable name="dlt">false</xsl:variable> 
   <xsl:variable name="colseperator">;</xsl:variable>
   <xsl:variable name="quote">"</xsl:variable> 
   <xsl:variable name="POEnabled">false</xsl:variable> 
   <xsl:variable name="fldnames">Supplier ID, Supplier Part ID, Manufacturer Part ID, Item Description, SPSC Code, Unit Price, Unit of Measure, Lead Time, Manufacturer Name, Supplier URL, Manufacturer URL, Market Price, Short Name, Language, Currency, Expiration Date, Effective Date, Classification Codes, Parametric Data, Parametric Name, PunchOut Enabled, Territory Available, Supplier Part Auxiliary ID, Delete</xsl:variable>
  
   
   <xsl:variable name="EmptyString"></xsl:variable>   
   <xsl:variable name="DefaultLeadTime">999</xsl:variable>      
   <xsl:variable name="DefaultLanguagePrefix">en</xsl:variable>         
   <xsl:variable name="DefaultLanguage">en</xsl:variable>            
   <xsl:variable name="DefaultCountryCode">US</xsl:variable>               
   <xsl:variable name="DefaultCountryTelephoneCode">011</xsl:variable>                     
   <xsl:variable name="DefaultDomain">DUNS</xsl:variable>                        
   <xsl:variable name="DefaultUSLanguage">en-US</xsl:variable>                           
   <xsl:variable name="DefaultComment"></xsl:variable>                              
   <xsl:variable name="LeadTime_Element_Name">LeadTime</xsl:variable>   
   <xsl:param name="buyorgname" select="'Park Avenue'"/>



<!-- Variable Name Definations Section Ends -->

   

<!-- Transformation Rules Section Starts -->

   <!-- Root Element Transformation Rule -->   
   <xsl:template match="/">                     
      <xsl:value-of select = "$CIFVersion"/>
      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>                                                 
      
      <xsl:value-of select = "$CHARSET"/>
      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>                                                 
                                           
      <xsl:value-of select = "$COMMENTS"/>
      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>                                                 
      
      <xsl:value-of select = "$DUNS"/>
      <xsl:value-of select="$dunsvalue"/>
      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>      
      
      <xsl:value-of select = "$LOADMODE"/>
      <xsl:value-of select="$lmode"/>
      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>                                                 
      
      <xsl:value-of select = "$SUPPLIERID_DOMAIN"/>
      <xsl:value-of select="$supiddomain"/>
      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>                    
      
      <xsl:value-of select = "$CURRENCY"/>
      <xsl:value-of select="$mecur"/>
      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>     
     
      <xsl:value-of select = "$CODEFORMAT"/>
      <xsl:value-of select="$codetype"/>
      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>                  

      <xsl:value-of select = "$FIELDNAMES"/>
      
      <xsl:value-of select="$fldnames"/>
      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>                        
      
      <xsl:value-of select = "$DATA"/>
      <xsl:text disable-output-escaping = "yes">&#13;</xsl:text>                  

      <xsl:apply-templates/>

      <xsl:value-of select = "$ENDOFDATA"/>
      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>                                                     
            
   </xsl:template>

   
   <xsl:template match="catentry">   
  

		<xsl:variable name="SupplierID">
		  <xsl:apply-templates select="//orgcode/@code"/>
		 </xsl:variable>               
       
       <xsl:variable name="SupplierPartID">
	     <xsl:apply-templates select="@partnumber"/>
       </xsl:variable>
     
	<xsl:variable name="ItemID">
	     <xsl:apply-templates select="@catentry_id"/>
       </xsl:variable>
     
		 <xsl:variable name="ManufacturerPartID">
	     <xsl:apply-templates select="@mfpartnumber"/>
       </xsl:variable>

		 <xsl:variable name="ItemDescription">
	     <xsl:apply-templates select="@longdescription"/>
       </xsl:variable>

 		 <xsl:variable name="SPSCCode">
		 		  <xsl:apply-templates select="@code"/>     
		 </xsl:variable>

       
    
    	<xsl:variable name="UnitPrice">
	     <xsl:apply-templates select="//offer[attribute::catentry_id=string($ItemID)]/@price"/>
      </xsl:variable>

		 <xsl:variable name="UOM">
         <xsl:apply-templates select="@quantitymeasure
"/>               
		 </xsl:variable>

       
	  <xsl:variable name="LeadTime"><xsl:value-of select = "$EmptyString"/></xsl:variable>

	  <xsl:variable name="ManufacturerName">
	     <xsl:apply-templates select="@mfname"/>
      </xsl:variable>

		<xsl:variable name="SupplierURL"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="ManufacturerURL"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="MarketPrice">
	     <xsl:apply-templates select="@listprice"/>
      </xsl:variable>

		<xsl:variable name="ShortName"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="Language">
	     <xsl:apply-templates select="@language_id"/>
      </xsl:variable>

		<xsl:variable name="Currency">
         <xsl:apply-templates select="//offer[attribute::catentry_id=string($ItemID)]/@currency"/>
        </xsl:variable>

	     
      
		<xsl:variable name="ExpirationDate"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="EffectiveDate"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="CommodityCodes"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="ParametricData"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="ParametricName"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="PunchOutEnabled"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="Territory"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="SupplierPartAuxID"><xsl:value-of select = "$EmptyString"/></xsl:variable>

		<xsl:variable name="Delete"><xsl:value-of select = "$EmptyString"/></xsl:variable>
 
<!-- Output block start -->
                            
      <xsl:value-of select = "$SupplierID"/>                                              
      <xsl:value-of select = "$FieldSeperator"/>                                                                  

      <xsl:value-of select = "$SupplierPartID"/>                                              
      <xsl:value-of select = "$FieldSeperator"/>                                                                  
      
      <xsl:value-of select = "$ManufacturerPartID"/>                                              
      <xsl:value-of select = "$FieldSeperator"/>                                                                  
      
	<xsl:value-of select = "$quote"/>
      <xsl:value-of select = "$ItemDescription"/>
	<xsl:value-of select = "$quote"/>                                              
      <xsl:value-of select = "$FieldSeperator"/>                                                                  
        
      <xsl:value-of select = "$SPSCCode"/>                                              
      <xsl:value-of select = "$FieldSeperator"/>                                                                  
      
      <xsl:value-of select = "$UnitPrice"/>                                              
      <xsl:value-of select = "$FieldSeperator"/>                                                                  

      <xsl:value-of select = "$UOM"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>          
      
      <xsl:value-of select = "$LeadTime"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>                                                     

      <xsl:value-of select = "$ManufacturerName"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>     

		<xsl:value-of select = "$SupplierURL"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>     

		<xsl:value-of select = "$ManufacturerURL"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>     
      
      <xsl:value-of select = "$MarketPrice"/>                                              
      <xsl:value-of select = "$FieldSeperator"/>       
      
      <xsl:value-of select = "$ShortName"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>                                                    

      <xsl:value-of select = "$Language"/>                                              
      <xsl:value-of select = "$FieldSeperator"/>      
      
      <xsl:value-of select = "$Currency"/>                                              
      <xsl:value-of select = "$FieldSeperator"/>   
   
		<xsl:value-of select = "$ExpirationDate"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>  

		<xsl:value-of select = "$EffectiveDate"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>  

		<xsl:value-of select = "$CommodityCodes"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>  

		<xsl:value-of select = "$ParametricData"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>  

		<xsl:value-of select = "$ParametricName"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>  

		<xsl:value-of select = "$PunchOutEnabled"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>  

		<xsl:value-of select = "$Territory"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>  

		<xsl:value-of select = "$SupplierPartAuxID"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>  

		<xsl:value-of select = "$Delete"/>                                                    
      <xsl:value-of select = "$FieldSeperator"/>  

      <xsl:text disable-output-escaping = "yes">&#13;&#10;</xsl:text>      

</xsl:template>

          
<!-- Transformation Rules Section Ends -->

</xsl:stylesheet>
